@@ -16,6 +16,7 @@ from rex.utilities import parse_table, SpawnProcessPool
 
 from reVX.handlers.outputs import Outputs
 from reVX.handlers.sc_points import SupplyCurvePoints
+from reVX.utilities.utilities import log_versions
 
 logger = logging.getLogger(__name__)
 
@@ -220,6 +221,9 @@ class PlexosPlants(Plants):
         points_per_worker : int, optional
             Number of points to create on each worker, by default 400
         """
+        log_versions(logger)
+        logger.info('Initializing PlexosPlants from plexos table with '
+                    '{} rows'.format(len(plexos_table)))
         self._plant_table = self._parse_plant_table(plexos_table)
         self._capacity = self.plant_table['plant_capacity'].values
 
@@ -354,7 +358,7 @@ class PlexosPlants(Plants):
         if plant_coords.shape[0] == 1:
             dist = dist.flatten()
 
-        R = 6373.0  # radius of the earth in kilometers
+        R = 6371.0  # radius of the earth in kilometers
 
         return dist * R
 
@@ -509,7 +513,7 @@ class PlexosPlants(Plants):
                                  .format((i + 1) * plants_per_worker,
                                          len(plant_table)))
         else:
-            logger.debug('Identifying plants in serial')
+            logger.info('Identifying plants in serial')
             for i, bus in plant_table.iterrows():
                 coords = \
                     bus[['latitude', 'longitude']].values.astype(float)
@@ -733,14 +737,36 @@ class PlantProfileAggregation:
         ----------
         plexos_table : str | pandas.DataFrame
             PLEXOS table of bus locations and capacity provided as a .csv,
-            .json, or pandas DataFrame
+            .json, or pandas DataFrame. Needs columns: latitude, longitude,
+            capacity
         sc_table : str | pandas.DataFrame
             Supply Curve table .csv or pre-loaded pandas DataFrame
         cf_fpath : str
-            Path to reV generation output .h5 file
+            Path to reV Generation output .h5 file to pull CF profiles from
+        plants : PlexosPlants | None
+            Optional PlexosPlants input. If None, PlexosPlants object will
+            be Initialized from the plexos table input.
+        dist_percentile : int, optional
+            Percentile to use to compute distance threshold using sc_gid to
+            SubStation distance , by default 90
+        lcoe_col : str, optional
+            LCOE column to sort by, by default 'total_lcoe'
+        lcoe_thresh : float, optional
+            LCOE threshold multiplier, exclude sc_gids above threshold,
+            by default 1.3
+        max_workers : int, optional
+            Number of workers to use for point and plant creation, 1 == serial,
+            > 1 == parallel, None == parallel using all available cpus,
+            by default None
+        points_per_worker : int, optional
+            Number of points to create on each worker, by default 400
+        plants_per_worker : int, optional
+            Number of plants to identify on each worker, by default 40
         offshore : bool, optional
             Include offshore points, by default False
         """
+        log_versions(logger)
+        logger.info('Initializing PlantProfileAggregation')
         self._plexos_table = self._parse_plexos_table(plexos_table)
         self._cf_fpath = cf_fpath
         self._cf_gid_map = self._parse_cf_gid_map(cf_fpath)
@@ -870,6 +896,7 @@ class PlantProfileAggregation:
         plexos_table : pandas.DataFrame
             Parsed and clean PLEXOS table
         """
+        logger.info('Parsing plexos table')
         plexos_table = parse_table(plexos_table)
         cols = ['generator', 'busid', 'busname', 'capacity', 'latitude',
                 'longitude', 'system']
@@ -926,6 +953,7 @@ class PlantProfileAggregation:
         cf_gid_map : dictionary
             Mapping of {res_gid: gen_gid}
         """
+        logger.info('Mapping reV resource GIDs to generation GIDs.')
         with Resource(cf_fpath) as f:
             res_gids = f.get_meta_arr('gid')
 
@@ -936,6 +964,17 @@ class PlantProfileAggregation:
 
         return cf_gid_map
 
+    @staticmethod
+    def _collapse_multi_list(multi_list):
+        """Collapse a list of lists into one list"""
+        if isinstance(multi_list, (pd.Series, pd.DataFrame)):
+            multi_list = multi_list.values.tolist()
+
+        if any(isinstance(x, (list, tuple)) for x in multi_list):
+            multi_list = [item for sublist in multi_list for item in sublist]
+
+        return multi_list
+
     def plants_meta(self):
         """
         Create plants meta data from filled plants DataFrames:
@@ -958,17 +997,18 @@ class PlantProfileAggregation:
         """
         plants_meta = []
         for pid, plant in self.plant_builds.items():
-            res_gids = plant['res_gids'].values.tolist()
-            plants_meta.append(pd.Series(
-                {'sc_gids': plant['sc_gid'].values.tolist(),
-                 'res_gids': res_gids,
-                 'gid_counts': plant['gid_counts'].values.tolist(),
-                 'gen_gids': [[self.cf_gid_map[gid] for gid in gids]
-                              for gids in res_gids],
-                 'res_cf_means': plant['cf_means'].values.tolist(),
-                 'build_capacity': plant['build_capacity'].values.tolist(),
-                 'cf_mean': np.hstack(plant['cf_means'].values).mean()},
-                name=pid))
+            single_meta = {
+                'sc_gids': plant['sc_gid'].values.tolist(),
+                'res_gids': plant['res_gids'].values.tolist(),
+                'gid_counts': plant['gid_counts'].values.tolist(),
+                'gen_gids': [[self.cf_gid_map[gid] for gid in gids]
+                             for gids in plant['res_gids'].values],
+                'res_cf_means': plant['cf_means'].values.tolist(),
+                'build_capacity': plant['build_capacity'].values.tolist()}
+            single_meta = {k: self._collapse_multi_list(v)
+                           for k, v in single_meta.items()}
+            single_meta['cf_mean'] = np.hstack(plant['cf_means'].values).mean()
+            plants_meta.append(pd.Series(single_meta, name=pid))
 
         plants_meta = pd.concat(plants_meta, axis=1).T
         plants_meta.index.name = 'plant_id'
@@ -1135,7 +1175,8 @@ class PlantProfileAggregation:
         ----------
         plexos_table : str | pandas.DataFrame
             PLEXOS table of bus locations and capacity provided as a .csv,
-            .json, or pandas DataFrame
+            .json, or pandas DataFrame. Needs columns: latitude, longitude,
+            capacity
         sc_table : str | pandas.DataFrame
             Supply Curve table .csv or pre-loaded pandas DataFrame
         cf_fpath : str
