@@ -5,4 +5,4 @@ reVX utilities.
 from .exclusions_converter import ExclusionsConverter
 from .forecasts import Forecasts
 from .output_extractor import output_extractor
-from .region import RegionClassifier
+from .region_classifier import RegionClassifier
