@@ -17,6 +17,7 @@ from reV.handlers.outputs import Outputs
 
 from reVX.handlers.geotiff import Geotiff
 from reVX.utilities.exceptions import ExclusionsCheckError
+from reVX.utilities.utilities import log_versions
 
 logger = logging.getLogger(__name__)
 
@@ -25,7 +26,6 @@ class ExclusionsConverter:
     """
     Convert exclusion layers between .h5 and .tif (geotiff)
     """
-
     def __init__(self, excl_h5, hsds=False, chunks=(128, 128), replace=True):
         """
         Parameters
@@ -40,6 +40,7 @@ class ExclusionsConverter:
         replace : bool, optional
             Flag to replace existing layers if needed, by default True
         """
+        log_versions(logger)
         self._excl_h5 = excl_h5
         self._hsds = hsds
         self._chunks = chunks
@@ -133,12 +134,12 @@ class ExclusionsConverter:
                 logger.debug('\t- Default chunks:\n{}'.format(chunks))
 
                 dst.create_dataset('latitude', shape=lat.shape,
-                                   dtype=lat.dtype, data=lat,
+                                   dtype=np.float32, data=lat,
                                    chunks=chunks)
                 logger.debug('\t- latitude coordiantes created')
 
                 dst.create_dataset('longitude', shape=lon.shape,
-                                   dtype=lon.dtype, data=lon,
+                                   dtype=np.float32, data=lon,
                                    chunks=chunks)
                 logger.debug('\t- longitude coordiantes created')
         except Exception:
